@@ -8,7 +8,7 @@ from .MSI import MSI
 from .MESI import MESI
 from .MOESI import MOESI
 
-protocols = {"VI": VI, "MSI": MSI, "MESI": MESI, "MOESI": MOESI}
+protocols = {"VI": VI, "MSI": MSI, "MESI": MESI, "MOESI": MESI}
 
 simulation_parameters = {
     # "Reads",
