@@ -1,4 +1,4 @@
-from Multiprocessor.CacheCoherence import protocols, simulation_parameters, Ops
+from CacheCoherence import protocols, simulation_parameters, Ops
 from random import randint
 import numpy as np
 import matplotlib.pyplot as plt
